summaryrefslogtreecommitdiffstats
path: root/languages/cpp/app_templates/opieapplet/simpleimpl.h
diff options
context:
space:
mode:
Diffstat (limited to 'languages/cpp/app_templates/opieapplet/simpleimpl.h')
-rw-r--r--languages/cpp/app_templates/opieapplet/simpleimpl.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/languages/cpp/app_templates/opieapplet/simpleimpl.h b/languages/cpp/app_templates/opieapplet/simpleimpl.h
index 19475367..7cca8ee7 100644
--- a/languages/cpp/app_templates/opieapplet/simpleimpl.h
+++ b/languages/cpp/app_templates/opieapplet/simpleimpl.h
@@ -26,8 +26,8 @@
* luckiy there is a macro for the reference counting
* We provide an Implementation of the interface.
*/
-#include <qwidget.h>
-#include <qptrlist.h>
+#include <tqwidget.h>
+#include <tqptrlist.h>
#include <qpe/taskbarappletinterface.h>
@@ -35,18 +35,18 @@
/*
* Because we only draw an Icon in a fixed width and height
* we declare and define %{APPNAME} here and you could use QLabel
* setPixmap or use QWidget and draw yourself.
* You might also want to reimplement mouse*Event to use some simple actions
*/
-class %{APPNAME} : public QWidget {
+class %{APPNAME} : public TQWidget {
Q_OBJECT
public:
- %{APPNAME}(QWidget *parent);
+ %{APPNAME}(TQWidget *parent);
~%{APPNAME}();
private:
- void mousePressEvent( QMouseEvent* );
- void paintEvent( QPaintEvent* );
- QPixmap *m_pix;
+ void mousePressEvent( TQMouseEvent* );
+ void paintEvent( TQPaintEvent* );
+ TQPixmap *m_pix;
};
class %{APPNAME}Impl : public TaskbarAppletInterface {
@@ -57,7 +57,7 @@ public:
QRESULT queryInterface( const QUuid&, QUnknownInterface** );
- QWidget *applet( QWidget* parent );
+ TQWidget *applet( TQWidget* parent );
int position()const;
/*
@@ -35,18 +35,18 @@
* Because we only draw an Icon in a fixed width and height
* we declare and define %{APPNAME} here and you could use QLabel
- * setPixmap or use QWidget and draw yourself.
+ * setPixmap or use TQWidget and draw yourself.
* You might also want to reimplement mouse*Event to use some simple actions
*/